@@ -17,26 +17,26 @@ flask_app = FlaskApp(SERVICE_CODE)
 flask_app.produce_handlers_and_documentation()
 
 app = flask_app.app
-app.config['LOGGER_NAME'] = 'ldap-services-api'
-app.config['TITLE'] = 'API LDAP'
-app.config['DESCRIPTION'] = "API pour l'annuaire LDAP de blueline"
-app.config['VERSION'] = __version__
+app.config["LOGGER_NAME"] = "ldap-services-api"
+app.config["TITLE"] = "API LDAP"
+app.config["DESCRIPTION"] = "API pour l'annuaire LDAP de blueline"
+app.config["VERSION"] = __version__
 app.logger.handlers = LOGS.logger.handlers
 app.register_blueprint(api)
 
 requests.post(
-    'https://{fqdn}/registry'.format(fqdn=APIGW),
+    "https://{fqdn}/registry".format(fqdn=APIGW),
     json={
-        'service': 'ldap',
-        'address': ADDRESS,
-        'version': int(eval(__version__)),
-        'service_code': SERVICE_CODE,
-        'host': HOSTNAME,
-        'status': 'up'
-        }
-    )
+        "service": "ldap",
+        "address": ADDRESS,
+        "version": int(eval(__version__)),
+        "service_code": SERVICE_CODE,
+        "host": HOSTNAME,
+        "status": "up",
+    },
+)
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     app.run(debug=True)
 
 # EOF
