@@ -7,16 +7,12 @@ import unittest
 
 
 class TestUserLdap(unittest.TestCase):
-
     def test_get_user(self):
-        user = User('rahim.remtola@staff.blueline.mg')
+        user = User("rahim.remtola@staff.blueline.mg")
         uids = user.uid
-        result = [
-            'rahim.remtola@staff.blueline.mg',
-            'rahim.remtola'
-            ]
+        result = ["rahim.remtola@staff.blueline.mg", "rahim.remtola"]
         self.assertEqual(uids, result)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
